Learn R Programming

systemfit (version 1.0-1)

residuals.systemfit: Residuals of systemfit object

Description

These functions extract the residuals from an object returned by systemfit.

Usage

## S3 method for class 'systemfit':
residuals( object, \dots )

## S3 method for class 'systemfit.equation': residuals( object, \dots )

Arguments

object
an object of class systemfit or systemfit.equation.
...
other arguments.

Value

  • residuals.systemfit returns a data.frame of residuals, where each column contains the residuals of one equation.

    residuals.systemfit.equation returns a vector of residuals.

See Also

systemfit, residuals

Examples

Run this code
data( "Kmenta" )
eqDemand <- consump ~ price + income
eqSupply <- consump ~ price + farmPrice + trend
system <- list( demand = eqDemand, supply = eqSupply )

## perform OLS on each of the equations in the system
fitols <- systemfit( system, data = Kmenta )

## residuals of all equations
residuals( fitols )

## residuals of the first equation
residuals( fitols$eq[[1]] )

## residuals of the second equation
residuals( fitols$eq[[2]] )

Run the code above in your browser using DataLab